package com.rjconsultores.ventaboletos.web.gui.controladores.configuracioneccomerciales;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Scope;
import org.springframework.stereotype.Controller;
import org.zkoss.util.resource.Labels;
import org.zkoss.zk.ui.Component;
import org.zkoss.zk.ui.Executions;
import org.zkoss.zk.ui.WrongValueException;
import org.zkoss.zk.ui.event.Event;
import org.zkoss.zul.Comboitem;
import org.zkoss.zul.Datebox;
import org.zkoss.zul.Longbox;
import org.zkoss.zul.Messagebox;
import org.zkoss.zul.Textbox;

import com.rjconsultores.ventaboletos.entidad.Ciudad;
import com.rjconsultores.ventaboletos.entidad.ClienteCorporativo;
import com.rjconsultores.ventaboletos.entidad.Empresa;
import com.rjconsultores.ventaboletos.exception.BusinessException;
import com.rjconsultores.ventaboletos.service.CiudadService;
import com.rjconsultores.ventaboletos.service.ClienteCorporativoService;
import com.rjconsultores.ventaboletos.service.EmpresaService;
import com.rjconsultores.ventaboletos.web.utilerias.MyComboboxCiudad;
import com.rjconsultores.ventaboletos.web.utilerias.MyComboboxEmpresa;
import com.rjconsultores.ventaboletos.web.utilerias.MyGenericForwardComposer;
import com.rjconsultores.ventaboletos.web.utilerias.MyListbox;
import com.rjconsultores.ventaboletos.web.utilerias.MyTextbox;

@Controller("editarClienteCorporativoController")
@Scope("prototype")
public class EditarClienteCorporativoController extends MyGenericForwardComposer {

	private static final String TITULO = "editarClienteCorporativoController.window.title";
	private static final long serialVersionUID = 1L;
	@Autowired
	private ClienteCorporativoService clienteCorpService;
	@Autowired	
	private EmpresaService empresaService;
	@Autowired
	private CiudadService ciudadService;

	private ClienteCorporativo clienteCorp;
	private MyListbox clienteCorpList;

	private List<Empresa> lsEmpresa;
	
	//Cliente
	private Datebox datCriacao;	
	private Longbox txtIdentificacao;
	private MyTextbox txtRazao;
	private Textbox txtEmail;
	private MyTextbox txtTelefone;
	private MyComboboxEmpresa cmbEmpresa;
	
	//Endereço
	private Textbox txtLogradouro;
	private MyComboboxCiudad cmbCidade;

	@Override
	public void doAfterCompose(Component comp) throws Exception {
		setLsEmpresa(empresaService.obtenerTodos());
				
		super.doAfterCompose(comp);
		
		clienteCorp = (ClienteCorporativo) Executions.getCurrent().getArg().get("clienteCorporativo");
		clienteCorpList = (MyListbox) Executions.getCurrent().getArg().get("clienteCorporativoList");
		
		if(clienteCorp.getEmpresaId() != null ) {
			selecionaEmpresaPorId(clienteCorp.getEmpresaId());
		}
		
		if(clienteCorp.getCiudadId() != null ) {
			Ciudad cid = ciudadService.obtenerID(clienteCorp.getCiudadId());
			Comboitem ciCidade = new Comboitem(cid.toString());
			ciCidade.setAttribute("value", cid);
			ciCidade.setValue(cid);			
			ciCidade.setParent(cmbCidade);
			cmbCidade.setSelectedItem(ciCidade);
		}		
	}

	public void onClick$btnSalvar(Event ev) throws InterruptedException {
		
		try {
			Comboitem empresa = cmbEmpresa.getSelectedItem();
			if( empresa != null ) {
				clienteCorp.setEmpresaId( ((Empresa)empresa.getValue()).getEmpresaId() );
			}
			
			Comboitem cidade = cmbCidade.getSelectedItem();
			if( cidade != null ) {
				clienteCorp.setCiudadId( ((Ciudad)cidade.getValue()).getCiudadId() );
			}
			
			clienteCorpService.suscribirActualizar(clienteCorp);
			clienteCorpList.updateItem(clienteCorp);

			Messagebox.show(
					Labels.getLabel("MSG.suscribirOK"),
					Labels.getLabel(TITULO),
					Messagebox.OK, Messagebox.INFORMATION);

			closeWindow();
		} catch (BusinessException ex) {
			Messagebox.show(
					ex.getMessage(),
					Labels.getLabel(TITULO),
					Messagebox.OK, Messagebox.ERROR);
		} catch (WrongValueException wex) {
			Messagebox.show(
					wex.getMessage(),
					Labels.getLabel(TITULO),
					Messagebox.OK, Messagebox.ERROR);			
		} catch (Exception ex) {
			Messagebox.show(
						Labels.getLabel("MSG.Error"),
						Labels.getLabel(TITULO),
						Messagebox.OK, Messagebox.ERROR);
		}
	}

	public void onClick$btnApagar(Event ev) throws InterruptedException {
		Integer resp = Messagebox.show(
					Labels.getLabel("MSG.borrarPergunta"),
					Labels.getLabel(TITULO),
					Messagebox.YES | Messagebox.NO, Messagebox.QUESTION);

		if (resp == Messagebox.YES) {

			clienteCorpService.borrar(clienteCorp);

			Messagebox.show(
						Labels.getLabel("MSG.borrarOK"),
						Labels.getLabel(TITULO),
						Messagebox.OK, Messagebox.INFORMATION);

			clienteCorpList.removeItem(clienteCorp);

			closeWindow();
		}
	}
	
	private void selecionaEmpresaPorId(Integer empresaId) {
		for (Empresa emp : lsEmpresa) {
			if(emp.getEmpresaId().equals(empresaId)) {
				Comboitem ciEmpresa = new Comboitem(emp.toString());
				ciEmpresa.setAttribute("value", emp);
				ciEmpresa.setValue(emp);
				ciEmpresa.setParent(cmbEmpresa);
				cmbEmpresa.setSelectedItem(ciEmpresa);
				break;
			}
		}
	}
	
	public ClienteCorporativo getClienteCorporativo() {
		return clienteCorp;
	}

	public void setClienteCorporativo(ClienteCorporativo clienteCorp) {
		this.clienteCorp = clienteCorp;
	}

	public ClienteCorporativo getClienteCorp() {
		return clienteCorp;
	}

	public void setClienteCorp(ClienteCorporativo clienteCorp) {
		this.clienteCorp = clienteCorp;
	}

	public MyListbox getClienteCorpList() {
		return clienteCorpList;
	}

	public void setClienteCorpList(MyListbox clienteCorpList) {
		this.clienteCorpList = clienteCorpList;
	}

	public MyTextbox getTxtRazao() {
		return txtRazao;
	}

	public void setTxtRazao(MyTextbox txtRazao) {
		this.txtRazao = txtRazao;
	}

	public MyTextbox getTxtTelefone() {
		return txtTelefone;
	}

	public void setTxtTelefone(MyTextbox txtTelefone) {
		this.txtTelefone = txtTelefone;
	}

	public Longbox getTxtIdentificacao() {
		return txtIdentificacao;
	}

	public void setTxtIdentificacao(Longbox txtIdentificacao) {
		this.txtIdentificacao = txtIdentificacao;
	}

	public Textbox getTxtEmail() {
		return txtEmail;
	}

	public void setTxtEmail(Textbox txtEmail) {
		this.txtEmail = txtEmail;
	}

	public List<Empresa> getLsEmpresa() {
		return lsEmpresa;
	}

	public void setLsEmpresa(List<Empresa> lsEmpresa) {
		this.lsEmpresa = lsEmpresa;
	}

	public MyComboboxEmpresa getCmbEmpresa() {
		return cmbEmpresa;
	}

	public void setCmbEmpresa(MyComboboxEmpresa cmbEmpresa) {
		this.cmbEmpresa = cmbEmpresa;
	}

	public Datebox getDatCriacao() {
		return datCriacao;
	}

	public void setDatCriacao(Datebox datCriacao) {
		this.datCriacao = datCriacao;
	}

	public Textbox getTxtLogradouro() {
		return txtLogradouro;
	}

	public void setTxtLogradouro(Textbox txtLogradouro) {
		this.txtLogradouro = txtLogradouro;
	}
}
