package com.rjconsultores.ventaboletos.web.utilerias.render;

import java.beans.IntrospectionException;
import java.beans.PropertyDescriptor;
import java.lang.reflect.Field;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;

import org.zkoss.zul.Listcell;
import org.zkoss.zul.Listitem;
import org.zkoss.zul.ListitemRenderer;

import com.rjconsultores.ventaboletos.anotacao.Renderizado;

public class RenderPadrao<E> implements ListitemRenderer {
	
	private Class<E> custom;

    public RenderPadrao(Class<E> classe) {
        this.custom = classe;
    }

    @Override
    public void render(Listitem lstm, Object o) throws Exception {
    	E cast = convertToE(o);
    	Field[] campos = cast.getClass().getDeclaredFields();
    	
    	Listcell lc;
    	for (Field campo : campos) {
    		if (campo.isAnnotationPresent(Renderizado.class)) {
    			lc = new Listcell(obterValorCampo(cast, campo).toString());
    	        lc.setParent(lstm);
    		}
    	}  
    	
        lstm.setAttribute("data", cast);
        
    }
    
	public E convertToE(Object o) {
	    if (o == null || !custom.isInstance(o)) {
	        throw new IllegalArgumentException("O objeto não é do tipo esperado: " + custom.getName());
	    }
	    return (E) o;
	}
	
	private static Object obterValorCampo(Object objeto, Field campo) throws IntrospectionException, IllegalAccessException, IllegalArgumentException, InvocationTargetException, IllegalArgumentException, InstantiationException, NoSuchMethodException, SecurityException  {        
        PropertyDescriptor pd = new PropertyDescriptor(campo.getName(), objeto.getClass());
  
        Method getter = pd.getReadMethod();
        
        if (getter != null) {
        	String valor = getter.invoke(objeto).toString();
        	Renderizado renderizado = campo.getAnnotation(Renderizado.class);
        	Class<? extends Enum<?>> conversor = renderizado.conversor();
        	
        	if( conversor == Renderizado.DefaultEnum.class) {
        		return valor;
        	}else {
        		try {
        			String nomeConversor = renderizado.metodoConversor();
        			Method metodoConversor = conversor.getMethod(nomeConversor, String.class);
        			Enum<?> enumResultado = (Enum<?>) metodoConversor.invoke(null, valor);
        			return enumResultado.toString();
        		}catch (Exception e) {
					return valor;
				}
        	}
            
        } else {
            throw new IllegalArgumentException("Getter não encontrado para o campo: " + campo.getName());
        }
    }    	
}
